@@ -3,10 +3,11 @@ from __future__ import unicode_literals
 
 
 VERSION_EXPLANATION = (
-    'Either specify a version of "2" (or "2.0") and place your service '
-    'definitions under the `services` key, or omit the `version` key and place '
-    'your service definitions at the root of the file to use version 1.\n'
-    'For more on the Compose file format versions, see '
+    'You might be seeing this error because you\'re using the wrong Compose file version. '
+    'Either specify a supported version ("2.0", "2.1", "3.0") and place your '
+    'service definitions under the `services` key, or omit the `version` key '
+    'and place your service definitions at the root of the file to use '
+    'version 1.\nFor more on the Compose file format versions, see '
     'https://docs.docker.com/compose/compose-file/')
 
 
@@ -38,7 +39,8 @@ class CircularReference(ConfigurationError):
 class ComposeFileNotFound(ConfigurationError):
     def __init__(self, supported_filenames):
         super(ComposeFileNotFound, self).__init__("""
-        Can't find a suitable configuration file in this directory or any parent. Are you in the right directory?
+        Can't find a suitable configuration file in this directory or any
+        parent. Are you in the right directory?
 
         Supported filenames: %s
         """ % ", ".join(supported_filenames))
